summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorNarayan Desai <desai@mcs.anl.gov>2004-10-22 18:36:22 +0000
committerNarayan Desai <desai@mcs.anl.gov>2004-10-22 18:36:22 +0000
commit4f0711d3c9d3415d5fc1e1cfe76f03c07e40c907 (patch)
treec620e291607136c5f21d0b054e880dd3cc26af63 /src
parent88d6fccc9aeb9f5193a4931c7d2ca5a555517d1b (diff)
downloadbcfg2-4f0711d3c9d3415d5fc1e1cfe76f03c07e40c907.tar.gz
bcfg2-4f0711d3c9d3415d5fc1e1cfe76f03c07e40c907.tar.bz2
bcfg2-4f0711d3c9d3415d5fc1e1cfe76f03c07e40c907.zip
pylint fixes
(Logical change 1.112) git-svn-id: https://svn.mcs.anl.gov/repos/bcfg/trunk/bcfg2@502 ce84e21b-d406-0410-9b95-82705330c041
Diffstat (limited to 'src')
-rw-r--r--src/lib/Client/Solaris.py7
-rw-r--r--src/lib/Server/Generators/servicemgr.py3
2 files changed, 6 insertions, 4 deletions
diff --git a/src/lib/Server/Generators/servicemgr.py b/src/lib/Server/Generators/servicemgr.py
index b658539c9..f84757111 100644
--- a/src/lib/Server/Generators/servicemgr.py
+++ b/src/lib/Server/Generators/servicemgr.py
@@ -1,6 +1,7 @@
#!/usr/bin/env python
+'''This generator provides service mappings'''
+__revision__ = '$Revision$'
-from elementtree.ElementTree import XML
from Bcfg2.Server.Generator import Generator, ScopedXMLFile
class servicemgr(Generator):
diff --git a/src/lib/Client/Solaris.py b/src/lib/Client/Solaris.py
index 1a6c5cbee..b27a3f12a 100644
--- a/src/lib/Client/Solaris.py
+++ b/src/lib/Client/Solaris.py
@@ -1,7 +1,8 @@
-# This is the bcfg2 support for debian
-# $Id: $
+# This is the bcfg2 support for solaris
+'''This provides (vestigal) bcfg2 support for Solaris'''
+__revision__ = '$Revision$'
-from Toolset import Toolset
+from Bcfg2.Client.Toolset import Toolset
def Detect():
# until the code works